@@ -9,16 +9,6 @@
 #'
 #' \if{html}{\figure{qrregresion2.png}{options: width="25\%" alt="Figure: qrmuestra1.png"}}
 #' \if{latex}{\figure{qrregresion2.png}{options: width=3cm}}
-
-#'
-#' @usage regresion.simple(x,
-#'                  var_depen = NULL,
-#'                  var_indepen = NULL,
-#'                  introducir = FALSE,
-#'                  inferencia = FALSE,
-#'                  confianza = 0.95,
-#'                  grafico = FALSE,
-#'                  exportar = FALSE)
 #'
 #' @param x Conjunto de datos. Es un dataframe con al menos 2 variables (2 columnas).
 #' @param var_depen Es un vector (numérico o carácter) que indica la variable dependiente.
@@ -86,16 +76,17 @@
 #' Murgui, J.S. y otros. (2002). Ejercicios de estadística Economía y Ciencias sociales. tirant lo blanch. ISBN: 9788484424673
 #'
 #' @examples
-#'
-#' ## Not run:
-#' ejemplo_regresion <- regresion.simple(turistas,
-#' var_depen=2,var_indepen=3,grafico=TRUE)
-#' ## End(Not run)
-#'
+#' \dontrun{
+#' ejemplo_regresion <- regresion.simple(
+#'   turistas,
+#'   var_depen = 2,
+#'   var_indepen = 3,
+#'   grafico = TRUE
+#' )
+#' }
 #' @importFrom stats cor
-#' @importFrom gridExtra grid.arrange
-#' @importFrom gridExtra arrangeGrob
-#' @import dplyr knitr ggplot2
+#' @importFrom utils capture.output
+#' @import dplyr knitr ggplot2 cowplot
 #'
 #' @export
 regresion.simple <- function(x,
@@ -526,56 +517,71 @@ regresion.simple <- function(x,
         theme(legend.position = "none")
 
       #plot <- gridExtra::grid.arrange(plot1,plot12,plot21,plot22, ncol=2, nrow=2)
-      plot <- gridExtra::grid.arrange(plot1,gridExtra::arrangeGrob(plot21,plot22), ncol=2)
+      #plot <- gridExtra::grid.arrange(plot1,gridExtra::arrangeGrob(plot21,plot22), ncol=2)
+      left_plot <- cowplot::plot_grid(plot21, plot22, ncol = 1)  # los apila verticalmente
+      plot <- cowplot::plot_grid(plot1, left_plot, ncol = 2)
 
     }
 
-
   if (exportar) {
+    # Prepara el nombre del archivo
+    filename <- paste("Resultados_regresion_simple_", format(Sys.time(), "%Y-%m-%d_%H.%M.%S"), ".xlsx", sep = "")
 
-    names(resumen) <- "Valor"
+    # Crear el workbook
+    wb <- openxlsx::createWorkbook()
 
-    filename <- paste("Resultados regresion simple"," (", Sys.time(), ").xlsx", sep = "")
-    filename <- gsub(" ", "_", filename)
-    filename <- gsub(":", ".", filename)
+    # Función auxiliar para añadir data.frames con formato
+    add_sheet_with_style <- function(wb, sheet_name, data) {
+      openxlsx::addWorksheet(wb, sheet_name)
+      openxlsx::writeData(wb, sheet_name, data, rowNames = TRUE)
 
-    if(isFALSE(introducir)){
-
-      if(inferencia){
-
-        names(resultados.parciales) <- "valor"
-
-        lista <- list(tabla,resultados.parciales,tabla.anova,modelo.regresion)
-
-        rio::export(lista, rowNames = TRUE, filename, sheetName=c("Resultados parciales",
-                                                                  "Resumen medidas",
-                                                                  "ANOVA",
-                                                                  "Modelo estimado"))
-      } else{
-
-        lista <- list(resumen,tabla)
-
-        rio::export(lista, rowNames = TRUE, filename, sheetName=c("Resumen",
-                                                                  "Resultados parciales"))
+      # Aplicar formato numérico a columnas numéricas
+      numeric_cols <- which(sapply(data, is.numeric))
+      if (length(numeric_cols) > 0) {
+        openxlsx::addStyle(
+          wb, sheet_name,
+          style = openxlsx::createStyle(numFmt = "0.0000"),
+          rows = 2:(nrow(data) + 1),
+          cols = numeric_cols + 1,  # +1 porque rowNames=TRUE añade una columna
+          gridExpand = TRUE
+        )
       }
-
-    } else{
-
-      if(inferencia){
-
-        lista <- list(resultados.parciales,tabla.anova,modelo.regresion)
-
-        rio::export(lista, rowNames = TRUE, filename, sheetName=c("Resumen medidas",
-                                                                "ANOVA",
-                                                                "Modelo estimado"))
-      } else{
-
-        rio::export(resumen, rowNames = TRUE, filename, sheetName="Resumen")
-
-      }
-
     }
 
+    if (isFALSE(introducir)) {
+      if (inferencia) {
+        names(resultados.parciales) <- "valor"
+
+        # Añadir todas las hojas
+        add_sheet_with_style(wb, "Resultados_parciales", tabla)
+        add_sheet_with_style(wb, "Resumen_medidas", resultados.parciales)
+        add_sheet_with_style(wb, "ANOVA", tabla.anova)
+
+        # Hoja para el modelo (manejo especial)
+        openxlsx::addWorksheet(wb, "Modelo_estimado")
+        openxlsx::writeData(wb, "Modelo_estimado", capture.output(modelo.regresion))
+
+      } else {
+        add_sheet_with_style(wb, "Resumen", resumen)
+        add_sheet_with_style(wb, "Resultados_parciales", tabla)
+      }
+
+    } else {
+      if (inferencia) {
+        add_sheet_with_style(wb, "Resumen_medidas", resultados.parciales)
+        add_sheet_with_style(wb, "ANOVA", tabla.anova)
+
+        # Hoja para el modelo (manejo especial)
+        openxlsx::addWorksheet(wb, "Modelo_estimado")
+        openxlsx::writeData(wb, "Modelo_estimado", capture.output(modelo.regresion))
+
+      } else {
+        add_sheet_with_style(wb, "Resumen", resumen)
+      }
+    }
+
+    # Guardar el archivo
+    openxlsx::saveWorkbook(wb, filename, overwrite = TRUE)
   }
 
   if(isFALSE(introducir)){
